#!/bin/sh
#
# @package      hubzero-submit-distributor
# @file         Scripts/tapis/cleanupjob.sh
# @author       Steve Clark <clarks@purdue.edu>
# @copyright    Copyright 2017-2017 Purdue University. All rights reserved.
# @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
#
# Copyright (c) 2017-2017 Purdue University
# All rights reserved.
#
# This file is part of: The HUBzero(R) Platform for Scientific Collaboration
#
# The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
# software: you can redistribute it and/or modify it under the terms of
# the GNU Lesser General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# HUBzero is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# HUBzero is a registered trademark of Purdue University.
#
if [ $# -ne 3 ] ; then
   echo usage: $0 jobWorkingDirectory jobScratchDirectory jobClass
   exit 64
fi

jobWorkingDirectory=$1
jobScratchDirectory=$2
jobClass=$3

binDirectory=$(dirname $(readlink -f $0))

cd ${jobWorkingDirectory}
exitStatus=$?

if [ ${exitStatus} -eq 0 ] ; then
   JOBID=0
   remoteJobIdFile=$(ls .__remote_jobid.[0-9]*_[0-9]* 2> /dev/null)
   if [ -n "${remoteJobIdFile}" ] ; then
      jobIdInstance=${remoteJobIdFile##*.}
      localJobId=${jobIdInstance%_*}
      instanceId=${jobIdInstance##*_}
      JOBID=$(cat ${remoteJobIdFile})
      if [ ${instanceId} -ne 0 ] ; then
         inputTarFile=${localJobId}_${instanceId}_input.tar.gz
         tapisDefinitionFile=${localJobId}_${instanceId}.tapis
         if [ -f ${tapisDefinitionFile} ] ; then
            systemId=$(grep ${inputTarFile} ${tapisDefinitionFile} | sed -e "s:/*JobInputs.*::" | sed -e "s:.*/::")
            python3 ${binDirectory}/removeJobInputs.py ${systemId} ${localJobId} ${instanceId}
         fi
         rm -f ${remoteJobIdFile}
      fi
   else
      remoteJobIdFile=$(ls ../.__remote_jobid.[0-9]*_[0-9]* 2> /dev/null)
      if [ -n "${remoteJobIdFile}" ] ; then
         remoteJobIdFile=$(basename ${remoteJobIdFile})
         jobIdInstance=${remoteJobIdFile##*.}
         localJobId=${jobIdInstance%_*}
         instanceId=${jobIdInstance##*_}
         if [ ${instanceId} -ne 0 ] ; then
            exitStatus=1
         fi
      fi
   fi
fi

exit ${exitStatus}
