import sys
import os

from simtool.db import DB
from TapisAPI import TapisAPI

PREFIX = '.simtool/'
SUFFIX = '.ipynb'
MAXDOWNLOADFAILURES = 4

def downloadFile(uri,
                 localPath):
   success = False
   nFail = 0
   while not success and nFail < MAXDOWNLOADFAILURES:
      try:
         response = tapisAPI.download_uri(uri=uri,local_path=localPath)
         success = True
      except:
         nFail += 1

   return success


exitStatus = 0

tapisAPI = TapisAPI()

jobId              = sys.argv[1]
jobOutputDirectory = sys.argv[2]

jobOutputs = tapisAPI.getJobOutputFilesList(jobId)
#print(jobOutputs)
if jobOutputs:
   simToolNotebook = None
   for jobOutput in jobOutputs:
      outputType = jobOutput['type']
      outputPath = jobOutput['path'].lstrip('/')
      if outputType == 'file':
         if outputPath.startswith(PREFIX):
            outputPath = outputPath[len(PREFIX):]
            if outputPath.endswith(SUFFIX):
               outputPath = outputPath[:-len(SUFFIX)]
               if not '/' in outputPath:
                  simToolNotebook = outputPath + SUFFIX
                  break

   if simToolNotebook:
      for jobOutput in jobOutputs:
         outputType = jobOutput['type']
         outputPath = jobOutput['path'].lstrip('/')
         outputURI  = jobOutput['_links']['self']['href']
         if outputType == 'file':
            if outputPath == simToolNotebook:
               if not os.path.isdir(jobOutputDirectory):
                  os.makedirs(jobOutputDirectory)

               success = downloadFile(outputURI,os.path.join(jobOutputDirectory,outputPath))
               if not success:
                  exitStatus = 1
                  sys.stderr.write("Download of %s failed.\n" % (outputPath))
               break

      if exitStatus == 0:
         try:
            db = DB(os.path.join(jobOutputDirectory,outputPath))
         except Exception as err:
            exitStatus = 1
            sys.stderr.write("File %s is not a valid notebook.\n" % (outputPath))
         else:
            simToolOutputFiles = db.getSavedOutputFiles()
#           print(simToolOutputFiles)
            for simToolOutputFile in simToolOutputFiles:
               for jobOutput in jobOutputs:
                  outputType = jobOutput['type']
                  outputPath = jobOutput['path'].lstrip('/')
                  outputURI  = jobOutput['_links']['self']['href']
                  if outputType == 'file':
                     if outputPath == simToolOutputFile:
                        success = downloadFile(outputURI,os.path.join(jobOutputDirectory,outputPath))
                        if not success:
                           exitStatus = 1
                           sys.stderr.write("Download of %s failed.\n" % (outputPath))
                        break
   else:
      exitStatus = 1
      sys.stderr.write("SimTool notebook not found.\n")
else:
   exitStatus = 1
   sys.stderr.write("Job outputs not found.\n")

sys.exit(exitStatus)

