#!/bin/sh
#
# @package      hubzero-submit-distributor
# @file         Scripts/tapis/transmitresults.sh
# @author       Steve Clark <clarks@purdue.edu>
# @copyright    Copyright 2017-2017 Purdue University. All rights reserved.
# @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
#
# Copyright (c) 2017-2017 Purdue University
# All rights reserved.
#
# This file is part of: The HUBzero(R) Platform for Scientific Collaboration
#
# The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
# software: you can redistribute it and/or modify it under the terms of
# the GNU Lesser General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# HUBzero is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# HUBzero is a registered trademark of Purdue University.
#
if [ $# -ne 2 ] ; then
   echo usage: $0 jobWorkingDirectory stageOutTarfile
   exit 64
fi

jobWorkingDirectory=$1
stageOutTarfile=$2

binDirectory=$(dirname $(readlink -f $0))

cd ${jobWorkingDirectory}
exitStatus=$?

if [ ${exitStatus} -eq 0 ] ; then
   localJobIdinstanceId=${stageOutTarfile%_*}
   localJobId=${localJobIdinstanceId%_*}
   instanceId=${localJobIdinstanceId#*_}
   if [ -f .__remote_jobid.${localJobId}_${instanceId} ] ; then
      JOBID=$(cat .__remote_jobid.${localJobId}_${instanceId})
      python3 ${binDirectory}/downloadJobOutputs.py ${JOBID} ${jobWorkingDirectory}
      exitStatus=$?
      if [ -f md5sums.start ] ; then
         md5sum --check md5sums.start 2> /dev/null | \
                grep ': OK' | sed -e "s/: OK//" | grep -v '.__' | \
                xargs --delimiter='\n' --max-lines=20 --no-run-if-empty /bin/rm -f
         find . -empty -type d -exec rmdir {} \; 2> /dev/null
         while [ $? -ne 0 ] ; do
            find . -empty -type d -exec rmdir {} \; 2> /dev/null
         done
      fi
   else
      exitStatus=1
   fi
fi

exit ${exitStatus}
