import sys
import os
import time
import tarfile
import tempfile
import shutil

from TapisAPI import TapisAPI
from TapisAPI import HTTPError

TIMESTAMPTRANSFERRED = ".__timestamp_transferred"

exitStatus = 0

tapisAPI = TapisAPI()

systemId         = sys.argv[1]
instanceToken    = sys.argv[2]
jobInputTarPath  = sys.argv[3]
auxiliaryTarFile = sys.argv[4]

directory = "/JobInputs/%s" % (instanceToken)
jobInputTarFile = os.path.basename(jobInputTarPath)
localJobId,instanceId = jobInputTarFile.split('_')[0:2]

if len(sys.argv) > 5:
   timestampTransferred = os.path.basename(sys.argv[5])
else:
   timestampTransferred = "%s.%s_%s" % (TIMESTAMPTRANSFERRED,localJobId,instanceId)

try:
   with open(jobInputTarPath,'rb') as fp:
      uploadFileResponse = tapisAPI.files.importData(systemId=systemId,filePath=directory,
                                                     fileToUpload=fp,fileType='raw')
except HTTPError as err:
   exitStatus = 1
   sys.stderr.write(err.strerror)
   sys.stderr.write("\n")
except Exception as err:
   exitStatus = 1
   sys.stderr.write(str(err))
   sys.stderr.write("\n")
else:
   if uploadFileResponse:
      print(uploadFileResponse['name'],uploadFileResponse['status'])

if exitStatus == 0:
   try:
      tmpDirectory = tempfile.mkdtemp(prefix="prestage_",dir=os.path.join(os.sep,'tmp'))
   except:
      tmpDirectory = None
      exitStatus = 1
      sys.stderr.write("TMP directory creation failed\n")
   else:
      currentDirectory = os.getcwd()
      try:
         os.chdir(tmpDirectory)
      except:
         exitStatus = 1
         sys.stderr.write("cd to TMP directory creation failed\n")
      else:
         now = int(time.time())
         with open(timestampTransferred,'w') as fp:
            fp.write("%d\n" % (now+1))

         tarFile = "%s_%s_timetransferred.tar.gz" % (localJobId,instanceId)
         fpTarFile = tarfile.open(tarFile,mode="w:gz")
         fpTarFile.add(timestampTransferred)
         fpTarFile.close()

         try:
            with open(tarFile,'rb') as fp:
               uploadFileResponse = tapisAPI.files.importData(systemId=systemId,filePath=directory,
                                                              fileToUpload=fp,fileType='raw')
         except HTTPError as err:
            exitStatus = 1
            sys.stderr.write(err.strerror)
            sys.stderr.write("\n")
         except Exception as err:
            exitStatus = 1
            sys.stderr.write(str(err))
            sys.stderr.write("\n")
         else:
            if uploadFileResponse:
               print(uploadFileResponse['name'],uploadFileResponse['status'])
      finally:
         os.chdir(currentDirectory)
         if tmpDirectory:
            shutil.rmtree(tmpDirectory,True)

if exitStatus == 0:
   if auxiliaryTarFile:
      if os.path.exists(auxiliaryTarFile):
         try:
            with open(auxiliaryTarFile,'rb') as fp:
               uploadFileResponse = tapisAPI.files.importData(systemId=systemId,filePath=directory,
                                                              fileToUpload=fp,fileType='raw')
         except HTTPError as err:
            exitStatus = 1
            sys.stderr.write(err.strerror)
            sys.stderr.write("\n")
         except Exception as err:
            exitStatus = 1
            sys.stderr.write(str(err))
            sys.stderr.write("\n")
         else:
            if uploadFileResponse:
               print(uploadFileResponse['name'],uploadFileResponse['status'])

sys.exit(exitStatus)
